@@ -23,6 +23,7 @@ from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.recipe import Recipe
 from tiddlyweb.model.user import User
 from tiddlyweb.util import sha
+from tiddlyweb.web.util import http_date_from_timestamp
 
 authorization = b64encode('cdent:cowpig')
 bad_authorization = b64encode('cdent:cdent')
@@ -138,20 +139,41 @@ def test_put_tiddler_txt_no_modified():
 def test_put_tiddler_json():
     http = httplib2.Http()
 
-    json = simplejson.dumps(dict(text='i fight for the users', tags=['tagone','tagtwo'], modifier='', modified='200805230303', created='200803030303'))
+    json = simplejson.dumps(dict(text='i fight for the users',
+        tags=['tagone','tagtwo'], modifier=''))
 
-    response, content = http.request('http://our_test_domain:8001/bags/bag0/tiddlers/TestTwo',
-            method='PUT', headers={'Content-Type': 'application/json'}, body=json)
+    response, content = http.request(
+            'http://our_test_domain:8001/bags/bag0/tiddlers/TestTwo',
+            method='PUT',
+            headers={'Content-Type': 'application/json',
+                'Content-Length': '0'},
+            body='')
+    assert response['status'] == '400'
+    assert 'unable to make json into' in content
 
-    assert response['status'] == '204', 'response status should be 204 is %s' % response['status']
+    response, content = http.request(
+            'http://our_test_domain:8001/bags/bag0/tiddlers/TestTwo',
+            method='PUT',
+            headers={'Content-Type': 'application/json'},
+            body='{"text": "}')
+    assert response['status'] == '400'
+    assert 'unable to make json into' in content
+
+    response, content = http.request(
+            'http://our_test_domain:8001/bags/bag0/tiddlers/TestTwo',
+            method='PUT', headers={'Content-Type': 'application/json'},
+            body=json)
+
+    assert response['status'] == '204'
     tiddler_url = response['location']
-    assert tiddler_url == 'http://our_test_domain:8001/bags/bag0/tiddlers/TestTwo', \
-            'response location should be http://our_test_domain:8001/bags/bag0/tiddlers/TestTwo is %s' \
-            % tiddler_url
+    assert (tiddler_url ==
+            'http://our_test_domain:8001/bags/bag0/tiddlers/TestTwo')
 
-    response, content = http.request(tiddler_url, headers={'Accept': 'application/json'})
+    response, content = http.request(tiddler_url,
+            headers={'Accept': 'application/json'})
     info = simplejson.loads(content)
-    assert response['last-modified'] == 'Fri, 23 May 2008 03:03:00 GMT'
+    now_time = http_date_from_timestamp('')
+    assert response['last-modified'].split(':', 1)[0] == now_time.split(':', 1)[0]
     assert info['title'] == 'TestTwo'
     assert info['text'] == 'i fight for the users'
 
@@ -167,6 +189,50 @@ def test_put_tiddler_json_with_slash():
     assert response['location'] == 'http://our_test_domain:8001/bags/bag0/tiddlers/Test%2FSlash'
 
 
+def test_put_tiddler_html_in_json():
+    http = httplib2.Http()
+
+    json = simplejson.dumps(dict(
+        text='<html><head><title>HI</title><body><h1>HI</h1></body></html>'))
+
+    response, content = http.request(
+            'http://our_test_domain:8001/bags/bag0/tiddlers/TestHTML',
+            method='PUT', headers={'Content-Type': 'application/json'},
+            body=json)
+
+    assert response['status'] == '204'
+    location = response['location']
+
+    response, content = http.request(location,
+            headers={'User-Agent': 'Mozilla'})
+    assert response['status'] == '200'
+    assert 'text/html' in response['content-type']
+    # Title should not be there
+    assert '<title>HI</title>' not in content
+    assert '<title>TiddlyWeb - TestHTML</title>' in content
+    assert '&lt;h1&gt;HI&lt;/h1&gt;' in content
+
+    json = simplejson.dumps(dict(
+        text='<html><head><title>HI</title><body><h1>HI</h1></body></html>',
+        type='text/html'))
+
+    response, content = http.request(
+            'http://our_test_domain:8001/bags/bag0/tiddlers/TestHTML',
+            method='PUT', headers={'Content-Type': 'application/json',
+                'User-Agent': 'Mozilla'},
+            body=json)
+
+    assert response['status'] == '204'
+    location = response['location']
+
+    response, content = http.request(location)
+    assert response['status'] == '200'
+    assert 'text/html' in response['content-type']
+    # Title should not be wrapping in tiddly info
+    assert '<title>HI</title>' in content
+    assert '<h1>HI</h1>' in content
+
+
 def test_put_tiddler_json_bad_path():
     """
     / in tiddler title is an unresolved source of some confusion.
@@ -529,25 +595,12 @@ def test_get_tiddler_via_recipe_with_perms():
     assert response['status'] == '403'
 
 def test_delete_tiddler_in_recipe():
+    """disabled in tiddlyweb 1.1"""
     http = httplib2.Http()
     response, content = http.request('http://our_test_domain:8001/recipes/long/tiddlers/tiddler8',
             method='DELETE')
-    assert response['status'] == '204'
+    assert response['status'] == '405'
 
-# there are multiple tiddler8s in the recipe
-    response, content = http.request('http://our_test_domain:8001/recipes/long/tiddlers/tiddler8',
-            method='DELETE')
-    assert response['status'] == '204'
-    response, content = http.request('http://our_test_domain:8001/recipes/long/tiddlers/tiddler8',
-            method='DELETE')
-    assert response['status'] == '204'
-    response, content = http.request('http://our_test_domain:8001/recipes/long/tiddlers/tiddler8',
-            method='DELETE')
-    assert response['status'] == '204'
-
-    response, content = http.request('http://our_test_domain:8001/recipes/long/tiddlers/tiddler8',
-            method='DELETE')
-    assert response['status'] == '404'
 
 def test_delete_tiddler_in_bag():
     http = httplib2.Http()
@@ -662,6 +715,12 @@ def test_binary_tiddler():
     assert response['status'] == '200'
     assert response['content-type'] == 'image/png'
 
+    # make sure a binary tiddler in a recipe doesn't cause a select
+    # filter to blow up
+    response, content = http.request('http://our_test_domain:8001/bags/bag1/tiddlers?select=text:hello',
+            method='GET')
+    assert response['status'] == '200'
+
     response, content = http.request(
             'http://our_test_domain:8001/recipes/long/tiddlers/peermorepng.json',
             method='GET')
