@@ -1,5 +1,11 @@
 """
-Serialize TiddlyWeb things for the sake of storage and the like.
+Serialize TiddlyWeb entities for the sake of taking input, sending
+output, or formatting entities for storage.
+
+This module provides the facade for accessing the possibly many modules
+which act as serializations. It is asked by calling code to provide a
+serialization for a given MIME type. Plugins may override what MIME
+types are handled and by what modules.
 """
 
 
@@ -19,7 +25,7 @@ class NoSerializationError(Exception):
 
 class Serializer(object):
     """
-    You must set object after initialization.
+    You must set serializer.object after initialization.
     """
 
     def __init__(self, engine, environ=None):
@@ -35,6 +41,8 @@ class Serializer(object):
         """
         Import the required Serialization.
         """
+        if self.engine is None:
+            raise NoSerializationError
         try:
             imported_module = __import__('tiddlyweb.serializations.%s' % self.engine,
                     {}, {}, ['Serialization'])
@@ -86,9 +94,9 @@ class Serializer(object):
         """
         return self.serialization.list_bags(bags)
 
-    def list_tiddlers(self, bag):
+    def list_tiddlers(self, tiddlers):
         """
         Provide a string representation of the tiddlers in the
-        provided bag in the current serialization.
+        provided Tiddlers collection.
         """
-        return self.serialization.list_tiddlers(bag)
+        return self.serialization.list_tiddlers(tiddlers)
