@@ -1,5 +1,8 @@
 """
-Miscellaneous utility functions for TiddlyWeb.
+A grab bag of miscellaneous utility functions for TiddlyWeb that don't
+fit in elsewhere.
+
+Web specific utilities are in tiddlyweb.web.util.
 """
 
 import logging
@@ -58,8 +61,9 @@ def read_config(global_config):
     try:
         from tiddlywebconfig import config as custom_config
         merge_config(global_config, custom_config, reconfig=False)
-    except ImportError:
-        pass # that's cool
+    except ImportError, exc:
+        if not exc.args[0].endswith('tiddlywebconfig'):
+            raise  # error within tiddlywebconfig.py
 
 
 def sha(data=''):
@@ -70,6 +74,28 @@ def sha(data=''):
     return sha1(data)
 
 
+def binary_tiddler(tiddler):
+    """
+    Return true if this Tiddler has a 'type' which suggests the
+    content of the tiddler is non-textual. This is usuallly used
+    to determine if the tiddler should be base64 encoded.
+    """
+    return (tiddler.type and tiddler.type != 'None'
+            and not pseudo_binary(tiddler.type))
+
+
+def pseudo_binary(content_type):
+    """
+    Return true if the content type should be treated as a pseudo-binary.
+    A pseudo binary is a type of textual content for which (this) TiddlyWeb
+    (instance) has no serialization. TiddlyWeb requires that such content
+    be uploaded encoded in UTF-8.
+    """
+    content_type = content_type.lower()
+    return (content_type.startswith('text/')
+            or content_type.endswith('+xml'))
+
+
 def read_utf8_file(filename):
     """
     Read a utf-8 encoded file.
@@ -129,7 +155,11 @@ def write_unlock(filename):
 
 
 def initialize_logging(config):
-# Avoid writing a tiddlyweb.log under some circumstances
+    """
+    Initialize the logging to tiddlyweb.log. We got to great lengths
+    to avoid writing a tiddlyweb.log file when we don't actually need 
+    or want to.
+    """
     try:
         try:
             current_command = sys.argv[0]
