@@ -13,6 +13,7 @@ from tiddlyweb.model.policy import create_policy_check
 from tiddlyweb.store import NoBagError, StoreMethodNotImplemented
 from tiddlyweb.serializer import Serializer, NoSerializationError
 from tiddlyweb.web import util as web
+from tiddlyweb.web.sendentity import send_entity
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 from tiddlyweb.web.listentities import list_entities
 from tiddlyweb.web.http import HTTP400, HTTP404, HTTP409, HTTP415
@@ -30,7 +31,7 @@ def delete(environ, start_response):
 
     usersign = environ['tiddlyweb.usersign']
 
-    bag = _get_bag(environ, bag_name, True)
+    bag = _get_bag(environ, bag_name)
     bag.policy.allows(usersign, 'manage')
     # reuse the store attribute that was set on the
     # bag when we "got" it.
@@ -53,27 +54,11 @@ def get(environ, start_response):
     """
     bag_name = _determine_bag_name(environ)
     bag_name = web.handle_extension(environ, bag_name)
-    bag = _get_bag(environ, bag_name, True)
+    bag = _get_bag(environ, bag_name)
 
     bag.policy.allows(environ['tiddlyweb.usersign'], 'manage')
 
-    try:
-        serialize_type, mime_type = web.get_serialize_type(environ)
-        serializer = Serializer(serialize_type, environ)
-        serializer.object = bag
-
-        content = serializer.to_string()
-    except NoSerializationError:
-        raise HTTP415('Content type not supported: %s' % mime_type)
-
-    start_response("200 Ok",
-            [('Content-Type', mime_type),
-                ('Vary', 'Accept')])
-
-    if isinstance(content, basestring):
-        return [content]
-    else:
-        return content
+    return send_entity(environ, start_response, bag)
 
 
 def get_tiddlers(environ, start_response):
@@ -82,14 +67,15 @@ def get_tiddlers(environ, start_response):
     bag. The information sent is dependent on the
     serialization chosen.
     """
+    store = environ['tiddlyweb.store']
     bag_name = _determine_bag_name(environ)
-    bag = _get_bag(environ, bag_name, True)
+    bag = _get_bag(environ, bag_name)
 
     usersign = environ['tiddlyweb.usersign']
     # will raise exception if there are problems
     bag.policy.allows(usersign, 'read')
 
-    return send_tiddlers(environ, start_response, bag)
+    return send_tiddlers(environ, start_response, tiddlers=store.list_bag_tiddlers(bag))
 
 
 def list_bags(environ, start_response):
@@ -118,13 +104,8 @@ def put(environ, start_response):
     usersign = environ['tiddlyweb.usersign']
 
     try:
-        bag.skinny = True
         bag = store.get(bag)
         bag.policy.allows(usersign, 'manage')
-        try:
-            delattr(bag, 'skinny')
-        except AttributeError:
-            pass
     except NoBagError:
         create_policy_check(environ, 'bag', usersign)
 
@@ -171,14 +152,12 @@ def _determine_bag_name(environ):
     return bag_name
 
 
-def _get_bag(environ, bag_name, skinny=False):
+def _get_bag(environ, bag_name):
     """
     Get the named bag out of the store.
     """
-    bag = Bag(bag_name)
-    if skinny:
-        bag.skinny = True
     store = environ['tiddlyweb.store']
+    bag = Bag(bag_name)
     try:
         bag = store.get(bag)
     except NoBagError, exc:
