@@ -1,6 +1,6 @@
 """
-WSGI Middleware apps that haven't gotten around
-to being extracted to their own modules.
+WSGI Middleware apps that haven't gotten around to being extracted to
+their own modules.
 """
 
 import logging
@@ -27,7 +27,7 @@ class Header(object):
     def __call__(self, environ, start_response):
         if environ['REQUEST_METHOD'] == 'HEAD':
             environ['REQUEST_METHOD'] = 'GET'
-            output = self.application(environ, start_response)
+            _ = self.application(environ, start_response)
             return []
         else:
             return self.application(environ, start_response)
@@ -46,11 +46,21 @@ class HTMLPresenter(object):
     def __call__(self, environ, start_response):
         output = self.application(environ, start_response)
         if self._needs_title(environ):
-            output = ''.join(output)
-            return [self._header(environ), output, self._footer(environ)]
+
+            def wrapped_output(output):
+                yield self._header(environ)
+                for item in output:
+                    yield item
+                yield self._footer(environ)
+                return
+
+            return wrapped_output(output)
         return output
 
     def _needs_title(self, environ):
+        """
+        Determine if we are outputting html to a browser.
+        """
         return ('tiddlyweb.title' in environ and 'Mozilla'
                 in environ['HTTP_USER_AGENT'])
 
@@ -202,8 +212,8 @@ class EncodeUTF8(object):
         self.application = application
 
     def __call__(self, environ, start_response):
-        return [_encoder(output) for output in
-                self.application(environ, start_response)]
+        return (_encoder(output) for output in
+                self.application(environ, start_response))
 
 
 def _encoder(string):
